/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.scripting.executor.groovy;

import com.liferay.dynamic.data.lists.model.DDLRecordSet;
import com.liferay.dynamic.data.mapping.model.DDMStructure;
import com.liferay.dynamic.data.mapping.model.DDMStructureConstants;
import com.liferay.dynamic.data.mapping.service.DDMStructureLocalServiceUtil;
import com.liferay.portal.kernel.service.ClassNameLocalServiceUtil;

/**
 * @author Michael C. Han
 */
class GroovyDDMStructure {

	GroovyDDMStructure(
		GroovySite groovySite_, String structureKey_, String name_,
		String description_, String xsd_) {

		groovySite = groovySite_;
		structureKey = structureKey_;
		name = name_;
		description = description_;
		xsd = xsd_;
	}

	void create(GroovyScriptingContext scriptingContext) {
		ddmStructure = GroovyDDMStructure.fetchStructure(
			scriptingContext, groovySite, structureKey);

		if (ddmStructure != null) {
			return;
		}

		ddmStructure = DDMStructureLocalServiceUtil.addStructure(
			scriptingContext.getDefaultUserId(), groovySite.group.getGroupId(),
			0, ClassNameLocalServiceUtil.getClassNameId(DDLRecordSet.class),
			null, GroovyScriptingContext.getLocalizationMap(name),
			GroovyScriptingContext.getLocalizationMap(description), xsd, "xml",
			DDMStructureConstants.TYPE_DEFAULT,
			scriptingContext.getServiceContext());
	}

	static DDMStructure fetchStructure(
		GroovyScriptingContext scriptingContext, GroovySite groovySite_,
		String structureKey_) {

		long classnameId = ClassNameLocalServiceUtil.getClassNameId(
			DDLRecordSet.class);

		return DDMStructureLocalServiceUtil.fetchStructure(
			groovySite.group.getGroupId(), classnameId, structureKey_);
	}

	DDMStructure ddmStructure;
	String description;
	GroovySite groovySite;
	String name;
	String structureKey;
	String xsd;
}